@@ -1,7 +1,8 @@
 #!/usr/bin/python
 # coding: utf8
 
-from base import Base
+from .base import Base
+
 
 class Arcgis(Base):
     provider = 'ArcGIS'
