@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # coding: utf8
 
-from base import Base
-from keys import bing_key
+from .base import Base
+from .keys import bing_key
 
 
 class Bing(Base):
@@ -84,6 +84,6 @@ class Bing(Base):
         return self._get_json_str('address-countryRegion')
 
 if __name__ == '__main__':
-    g = Bing('453 Booth street, Ottawa, ON')
+    g = Bing('453 Booth Street, Ottawa ON')
     g.help()
     g.debug()
\ No newline at end of file
