@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # coding: utf8
 
-from base import Base
-from location import Location
+from .base import Base
+from .location import Location
 import time
 
 class Timezone(Base):
